pub struct CacheRecord {
pub uri: String,
pub data: Bytes,
pub meta: Bytes,
}Expand description
A record in a cache. This is designed to represent values in a simple
key-value store, and so it has minimal fields. The uri field is the
key, and the data field is the value. An extra meta field is included
for additional information that may be useful, like timestamps or other
bits that might not make sense to store in the data field.
Fields
uri: StringThe URI of the record
data: BytesThe main data of the record
meta: BytesAny additional metadata
Implementations