Struct intrepid_model::Event

source ·
pub struct Event {
    pub stream_name: String,
    pub kind: EventKind,
    pub data: Bytes,
}
An event in a stream. This is slimmer than the EventRecord type, and is used for most public interactions with events.

Fields

stream_name: String

The name of the stream that the event is in.

kind: EventKind

The kind of event.

data: Bytes

The main data of the event.

Implementations

source

impl Event

source

pub fn entry(stream_name: impl AsRef<str>, data: impl Into<Bytes>) -> Self

Create a new entry event.

source

pub fn read_marker( stream_name: impl AsRef<str>, subscriber_name: impl AsRef<str>, position: i64, ) -> Self

Create a new read marker event.

source

pub async fn publish(&self, repo: &impl EventRepo) -> Result<(), EventRepoError>

Publish the event to the given repository.