IntoCache

Trait IntoCache 

pub trait IntoCache {
    // Required method
    fn into_cache(self) -> CacheRecord;
}
A trait for types that can be converted into a cache record. Any given type that implements this trait can be inserted into a cache.

Required Methods

fn into_cache(self) -> CacheRecord

Consume the type, producing a CacheRecord

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors