IntoEvent

Trait IntoEvent 

pub trait IntoEvent: Clone {
    // Required method
    fn into_event(self) -> Event;
}
A trait for types that can be converted into an event. Any given type that implements this trait can be published as an event.

Required Methods

fn into_event(self) -> Event

Consume the type, producing an Event

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors