IntrepidRepo

Trait IntrepidRepo 

pub trait IntrepidRepo: CacheRepo + EventRepo { }
An intrepid repository combines the functionality of a cache and an event repo, and is automatically implemented for any type that implements both.

This lets you establish an interface that expects both types, and then use any type that implements both without having to specify both types every time.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T> IntrepidRepo for T
where T: CacheRepo + EventRepo,