SubscriptionTopic

Trait SubscriptionTopic 

pub trait SubscriptionTopic {
    // Required method
    fn stream_name(&self) -> SubscriptionName;
}
Implement this trait for a type that can be used as a subscription topic. That means that the type can be used to create a subscription to a stream of events using the Subscription type.

Required Methods

fn stream_name(&self) -> SubscriptionName

Get the name of the stream that the subscription will read from.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors