Struct intrepid_model::EventConnection

source ·
pub struct EventConnection<Repo> {
    pub repo: Repo,
    pub own_stream_name: String,
    pub target_stream_name: String,
}
A connection to an event repo. Event connections are meant to represent long running or repeated access to a log of events. They keep track of the last event they read and will only read events that have occurred since that event. This allows them to be used in a streaming context, where they can be run in the background or polled for new events.

Fields

repo: Repo

The underlying repository.

own_stream_name: String

The name of the stream that this connection marks reads in. This is essentially the identity of the connection. Changing this will cause the connection to read from the beginning of the target stream.

target_stream_name: String

The name of the stream that this connection is reading from. The connection will ignore events from other streams.

Implementations

source

impl<Repo> EventConnection<Repo>
where Repo: EventRepo + Send + Sync + 'static,

source

pub fn new( repo: Repo, target_stream_name: impl AsRef<str>, own_stream_name: impl AsRef<str>, ) -> Self

Create a new connection.

source

pub fn into_stream(self) -> impl Stream<Item = Result<Frame, EventRepoError>>

Consume the connection and return an async stream of events.

source

pub async fn publish<EventCandidate>( &self, event: EventCandidate, ) -> Result<(), EventRepoError>
where EventCandidate: IntoEvent + Send,

Publish an event to the target stream.

source

pub async fn process<FrameService>( &self, service: FrameService, ) -> Result<(), EventRepoError>
where FrameService: Service<Frame> + Send,

Process all pending events in the target stream.