Struct intrepid_model::IntrepidConnection

source ·
pub struct IntrepidConnection<Repo> {
    pub repo: Repo,
}
A connection to an intrepid repository that combines the functionality of a cache and an event connection.

Fields

repo: Repo

The underlying repository.

Implementations

source

impl<Repo> IntrepidConnection<Repo>
where Repo: InterpidRepo + Clone + Send + Sync + 'static,

source

pub fn new(repo: Repo) -> Self

Create a new connection.

source

pub fn event_connection( &self, target_stream_name: impl AsRef<str> + Send, own_stream_name: impl AsRef<str> + Send, ) -> EventConnection<Repo>

Accept a stream name and marker stream name, and return an event connection

source

pub fn cache_connection(&self) -> CacheConnection<Repo>

Get a cache connection

source

pub fn into_inner(self) -> Repo

Consume the connection and return the inner repository