Struct intrepid_model::IntrepidConnection
source · pub struct IntrepidConnection<Repo> {
pub repo: Repo,
}Expand description
A connection to an intrepid repository that combines the functionality of a cache and an event connection.
Fields
repo: RepoThe underlying repository.
Implementations
sourceimpl<Repo> IntrepidConnection<Repo>
impl<Repo> IntrepidConnection<Repo>
sourcepub fn event_connection(
&self,
target_stream_name: impl AsRef<str> + Send,
own_stream_name: impl AsRef<str> + Send,
) -> EventConnection<Repo>
pub fn event_connection( &self, target_stream_name: impl AsRef<str> + Send, own_stream_name: impl AsRef<str> + Send, ) -> EventConnection<Repo>
Accept a stream name and marker stream name, and return an event connection
sourcepub fn cache_connection(&self) -> CacheConnection<Repo>
pub fn cache_connection(&self) -> CacheConnection<Repo>
Get a cache connection
sourcepub fn into_inner(self) -> Repo
pub fn into_inner(self) -> Repo
Consume the connection and return the inner repository