Trait intrepid_model::InterpidRepo
source · pub trait InterpidRepo: CacheRepo + EventRepo { }Expand description
An intrepid repository combines the functionality of a cache and an event repo, and is automatically implemented for any type that implements both.
This lets you establish an interface that expects both types, and then use any type that implements both without having to specify both types every time.
Object Safety
This trait is not object safe.