Trait intrepid_model::IntoEvent

source ·
pub trait IntoEvent: Clone {
    // Required method
    fn into_event(self) -> Event;
}
A trait for types that can be converted into an event. Any given type that implements this trait can be published as an event.

Required Methods

source

fn into_event(self) -> Event

Consume the type, producing an Event

Object Safety

This trait is not object safe.

Implementors